clear
use "Linked Mortality & Census Sample.dta"
set more off

gen combinemort = 0
replace combinemort = 1 if(icd1==1 | icd1==5 | icd1==6 | icd1==7 | icd1==8 | ///
	icd1==9 | icd1==10 | icd1==13 | icd1==14 | icd1==28 | icd1==29 | ///
	icd1==92 | icd1==104 | icd1==105 | icd1==61) 
label var combinemort "Combined excess mortality"

gen agecat2 = 0
replace agecat2 = 1 if(age<15)
replace agecat2 = 2 if(age>=15)
label var agecat2 "Adult and Child Dichotomy"

gen irish1870 = 0
replace irish1870 = 1 if(epob==2 & decade<3)
label var irish1870 "Irish and prior to 1870"

gen candn1890 = 0
replace candn1890 = 1 if(epob==3 & decade<5)
label var candn1890 "Canadian and prior to 1890"

gen estrn1920 = 0
replace estrn1920 = 1 if(epob==6 | epob==7 | epob==11 | epob==13)
label var estrn1920 "Eastern European and prior to 1920"

gen citydenom = 0
replace citydenom = 2922 if(decade==2)
replace citydenom = 3140 if(decade==3)
replace citydenom = 3204 if(decade==4)
replace citydenom = 2851 if(decade==5)
replace citydenom = 3791 if(decade==6)

label var citydenom "Adult sample size by decade"

gen yr1cityLoss = 0
replace yr1cityLoss = 18 if(decade==2)
replace yr1cityLoss = 54 if(decade==3)
replace yr1cityLoss = 44 if(decade==4)
replace yr1cityLoss = 39 if(decade==5)
replace yr1cityLoss = 32 if(decade==6)

label var yr1cityLoss "Sample size by city for each decade"

gen twoYrDenom = 0
replace twoYrDenom = (citydenom + (citydenom - (yr1cityLoss*1.5)))
label var twoYrDenom "2 year sampling period adjustment"

sort ifnum ucid
gen famyipums=ipums
replace famyipums=famyipums[_n-1] if ifnum>10000 & ifnum==ifnum[_n-1]
label variable famyipums "Family IPUMS score as Heads IPUMS"
replace famyipums = 0 if(famyipums==.)

gen famyocc=occ80
replace famyocc=famyocc[_n-1] if ifnum>10000 & ifnum==ifnum[_n-1]
label variable famyocc "Family occ80 as Heads occ80"

gen lowTnTSES = 0 
replace lowTnTSES = 1 if(famyocc==61 | famyocc==62 | famyocc==76 | famyocc==78 | ///
	famyocc==82 | famyocc==87 | famyocc==89 | famyocc==93)
label var lowTnTSES "Low SES Trade & Transportation Occupations"

gen lowMMMSES = 0 
replace lowMMMSES = 1 if(famyocc==132 | famyocc==142 | famyocc==146 | ///
	famyocc==177 | famyocc==181 | famyocc==196 | famyocc==206 | famyocc==207 | ///
	famyocc==215 | famyocc==226 | famyocc==237 | famyocc==262)
label var lowMMMSES "Low SES Mfg., Mech., & Mining Occupations"

gen lowSESocc = 0 
replace lowSESocc = 1 if(lowTnTSES==1 | lowMMMSES==1)
label var lowSESocc "Fmailies in Low T&T or MMM Occupations"

gen famreal = 0
replace famreal = 1 if(tcfreal>0)
label var famreal "Family has census real estate wealth"

gen fampers = 0 
replace fampers = 1 if(tcfpers>0)
label var fampers "family has census personal wealth"

keep if agecat==2

char decade[omit] 2 //1860 as comparison group
xi : poisson combinemort i.decade fampers famreal irish1870 candn1890 ///
	estrn1920 famyipums lowSESocc, exposure(twoYrDenom) irr
