clear 
use "Population Mortality Data.dta" 
set more off

gen Diarrhoea = 0
replace Diarrhoea = 1 if(icd1==13 | icd1==14 | icd1==104 | icd1==105) 
label var Diarrhoea "Diarrhoea and enteritis"

gen Tuberculosis = 0
replace Tuberculosis = 1 if(icd1==28 | icd1==29 | icd1==92) 
label var Tuberculosis "Tuberculosis & Pnumonia"

gen Typhoid = 0
replace Typhoid = 1 if(icd1==1)
label var Typhoid "Typhoid Fever"

gen Smallpox = 0
replace Smallpox = 1 if(icd1==5)
label var Smallpox "Smallpox"

gen Measeles = 0
replace Measeles = 1 if(icd1==6)
label var Measeles "Measeles"

gen Scarlet = 0
replace Scarlet = 1 if(icd1==7)
label var Scarlet "Scarlet"

gen Diptheria = 0
replace Diptheria = 1 if(icd1==9)
label var Diptheria "Diptheria & Croup"

collapse (sum) Diarrhoea Tuberculosis Typhoid Smallpox Measeles Scarlet ///
	Diptheria (mean) popdenom_cityyear, by(deathyear)

gen DiarrhoeaRate = (Diarrhoea / popdenom_cityyear) * 1000
gen TuberculosisRate = (Tuberculosis / popdenom_cityyear) * 1000
gen TyphoidRate = (Typhoid / popdenom_cityyear) * 1000	
gen SmallpoxRate = (Smallpox / popdenom_cityyear) * 1000
gen MeaselesRate = (Measeles / popdenom_cityyear) * 1000
gen ScarletRate = (Scarlet / popdenom_cityyear) * 1000	
gen DiptheriaRate = (Diptheria / popdenom_cityyear) * 1000	

list deathyear DiarrhoeaRate TuberculosisRate TyphoidRate SmallpoxRate ///
	MeaselesRate ScarletRate DiptheriaRate, noobs clean
