clear 
use "Population Mortality Data.dta" 
set more off

gen decadeDiv = 0
replace decadeDiv = 1 if(deathyear>=1890)
label define decadeDiv 0 "before 1890" 1 "1890 & later"
label values decadeDiv decadeDiv

gen agecat2 = 0
replace agecat2 = 1 if(age<15)
replace agecat2 = 2 if(age>=15)
label var agecat2 "1 = younger than 15, 2 = 15 and older"

gen Diarrhoea = 0
replace Diarrhoea = 1 if(icd1==13 | icd1==14 | icd1==104 | icd1==105) 
label var Diarrhoea "Diarrhoea and enteritis"

gen Tuberculosis = 0
replace Tuberculosis = 1 if(icd1==28 | icd1==29 | icd1==92) 
label var Tuberculosis "Tuberculosis & Pnumonia"

gen Typhoid = 0
replace Typhoid = 1 if(icd1==1)
label var Typhoid "Typhoid Fever"

gen Smallpox = 0
replace Smallpox = 1 if(icd1==5)
label var Smallpox "Smallpox"

gen Measeles = 0
replace Measeles = 1 if(icd1==6)
label var Measeles "Measeles"

gen Scarlet = 0
replace Scarlet = 1 if(icd1==7)
label var Scarlet "Scarlet"

gen Whooping = 0
replace Whooping = 1 if(icd1==8)
label var Whooping "Whooping Cough"

gen Diptheria = 0
replace Diptheria = 1 if(icd1==9)
label var Diptheria "Diptheria & Croup"

gen  Influenzia = 0
replace Influenzia = 1 if(icd1==10)
label var Influenzia "Influenzia"

gen Meningitis = 0 
replace Meningitis = 1 if(icd==61)
label var Meningitis "Meningitis"

gen SelectedCauses = 0 
replace SelectedCauses = 1 if(icd1==1 | icd1==5 | icd1==6 | icd1==7 | icd1==8 | ///
	icd1==9 | icd1==10 | icd1==61 | icd1==28 | icd1==29 | icd1==92 | ///
	icd1==13 | icd1==14 | icd1==104 | icd1==105)
label var SelectedCauses "Death from Selected Causes"

gen OtherCauses = 0
replace OtherCauses = 1 if(SelectedCauses==0)
label var OtherCauses "Death by All Other Causes"

collapse (sum) Diarrhoea Tuberculosis Typhoid Smallpox Measeles Scarlet ///
	Whooping Diptheria Influenzia Meningitis SelectedCauses OtherCauses ///
	age_categories, by(agecat2 decadeDiv deathyear popdenom_age)
	
collapse (sum) Diarrhoea Tuberculosis Typhoid Smallpox Measeles Scarlet ///
	Whooping Diptheria Influenzia Meningitis SelectedCauses OtherCauses ///
	age_categories popdenom_age, by(agecat2 decadeDiv)

gen DiarrhoeaRate = (Diarrhoea / popdenom_age) *1000
gen TuberculosisRate = (Tuberculosis / popdenom_age) *1000
gen TyphoidRate = (Typhoid / popdenom_age) *1000
gen SmallpoxRate = (Smallpox / popdenom_age) *1000
gen MeaselesRate = (Measeles / popdenom_age) *1000
gen ScarletRate = (Scarlet / popdenom_age) *1000
gen WhoopingRate = ( Whooping / popdenom_age) *1000
gen DiptheriaRate = (Diptheria / popdenom_age) *1000
gen InfluenziaRate = (Influenzia / popdenom_age) *1000
gen MeningitisRate = (Meningitis / popdenom_age) *1000
gen SelectedCausesRate = (SelectedCauses / popdenom_age) *1000
gen OtherCausesRate = (OtherCauses / popdenom_age) *1000

list DiarrhoeaRate DiptheriaRate InfluenziaRate MeaselesRate MeningitisRate ///
	ScarletRate SmallpoxRate TyphoidRate TuberculosisRate WhoopingRate ///
	SelectedCausesRate OtherCausesRate if (agecat2==1 & decadeDiv==0), noobs clean
	
list DiarrhoeaRate DiptheriaRate InfluenziaRate MeaselesRate MeningitisRate ///
	ScarletRate SmallpoxRate TyphoidRate TuberculosisRate WhoopingRate ///
	SelectedCausesRate OtherCausesRate if (agecat2==1 & decadeDiv==1), noobs clean
	
list DiarrhoeaRate DiptheriaRate InfluenziaRate MeaselesRate MeningitisRate ///
	ScarletRate SmallpoxRate TyphoidRate TuberculosisRate WhoopingRate ///
	SelectedCausesRate OtherCausesRate if (agecat2==2 & decadeDiv==0), noobs clean
	
list DiarrhoeaRate DiptheriaRate InfluenziaRate MeaselesRate MeningitisRate ///
	ScarletRate SmallpoxRate TyphoidRate TuberculosisRate WhoopingRate ///
	SelectedCausesRate OtherCausesRate if (agecat2==2 & decadeDiv==1), noobs clean
